{ lib, pkgs, config, myconfig, mylibs, ... }:
let
    infcloud = pkgs.callPackage ./infcloud.nix {};
    davical = pkgs.callPackage ./davical.nix {
      env = myconfig.env.tools.davical;
    };

    cfg = config.services.myWebsites.tools.dav;
in {
  options.services.myWebsites.tools.dav = {
    enable = lib.mkEnableOption "enable dav website";
  };

  config = lib.mkIf cfg.enable {
    security.acme.certs."eldiron".extraDomains."dav.immae.eu" = null;

    services.myWebsites.tools.modules = davical.apache.modules;

    services.myWebsites.tools.vhostConfs.dav = {
      certName    = "eldiron";
      hosts       = ["dav.immae.eu" ];
      root        = null;
      extraConfig = [
        infcloud.apache.vhostConf
        davical.apache.vhostConf
      ];
    };

    services.myPhpfpm.poolConfigs = {
      davical = davical.phpFpm.pool;
    };

  };
}

